ConcatCombination
=================

.. currentmodule:: pykeen.nn.combination

.. autoclass:: ConcatCombination
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ConcatCombination.forward
      ~ConcatCombination.iter_extra_repr

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: iter_extra_repr
